const std = @import("std");
const cwd = std.fs.cwd;
const json = std.json;
const print = std.debug.print;
const oracleFileName = "oracle-data/oracle-cards-20240701090158.json";

const Card = struct {
    name: []const u8 = "", //string
    mana_cost: []const u8 = "", //string
    cmc: f32 = 0, //technically a float? but I think we can always cast safely cast. EDIT: NOPE
    type_line: []const u8 = "", //string
    oracle_text: []const u8 = "", //string
    power: []const u8 = "", //coerced to string
    toughness: []const u8 = "", //coerced to string
    card_faces: ?[]Card = null, //array of cards
};

const testCardName = "Raffine, Scheming Seer";

const cardList = std.MultiArrayList(Card);
pub fn main() !void {
    var arena = std.heap.ArenaAllocator.init(std.heap.page_allocator);
    defer arena.deinit();
    const allocator = arena.allocator();

    var cards = std.StringArrayHashMap.init(allocator);

    var timer = try std.time.Timer.start();
    const oracleFileSize = (try cwd().statFile(oracleFileName)).size;
    const oracleFile = try cwd().readFileAlloc(allocator, oracleFileName, oracleFileSize);
    var cardStrings = std.mem.splitSequence(u8, oracleFile, "{\"object\":\"card\",");
    while (cardStrings.next()) |cardText| {
        if(cardText.len > 5) {
            const paddedText = try std.mem.concat(allocator, u8, &[_][]const u8{"{", cardText});
            const trimmedText = std.mem.trimRight(u8, paddedText, ",\n]");
            const card = try std.json.parseFromSlice(Card, allocator, trimmedText, .{.ignore_unknown_fields = true});
            try cards.put(allocator, card.value.name, card.value);
        }
    }
    for(cards.items(.name), 0..) |name, idx| {
        if(std.mem.eql(u8, name, testCardName)) print("{any}\n", .{cards.get(idx)});
    }
    print("{d}\n", .{timer.read() / 1_000_000_000});
}
